==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/servicelinker/kotlin/inputs/ServicePrincipalSecretAuthInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicelinker.kotlin.inputs

import com.pulumi.azurenative.servicelinker.inputs.ServicePrincipalSecretAuthInfoArgs.builder
import com.pulumi.azurenative.servicelinker.kotlin.enums.DeleteOrUpdateBehavior
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The authentication info when authType is servicePrincipal secret
 * @property authType The authentication type.
 * Expected value is 'servicePrincipalSecret'.
 * @property clientId ServicePrincipal application clientId for servicePrincipal auth.
 * @property deleteOrUpdateBehavior Indicates whether to clean up previous operation when Linker is updating or deleting
 * @property principalId Principal Id for servicePrincipal auth.
 * @property roles Optional, this value specifies the Azure roles to be assigned. Automatically
 * @property secret Secret for servicePrincipal auth.
 * @property userName Username created in the database which is mapped to a user in AAD.
 */
public data class ServicePrincipalSecretAuthInfoArgs(
    public val authType: Output<String>,
    public val clientId: Output<String>,
    public val deleteOrUpdateBehavior: Output<Either<String, DeleteOrUpdateBehavior>>? = null,
    public val principalId: Output<String>,
    public val roles: Output<List<String>>? = null,
    public val secret: Output<String>,
    public val userName: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.servicelinker.inputs.ServicePrincipalSecretAuthInfoArgs> {
    override fun toJava():
        com.pulumi.azurenative.servicelinker.inputs.ServicePrincipalSecretAuthInfoArgs =
        com.pulumi.azurenative.servicelinker.inputs.ServicePrincipalSecretAuthInfoArgs.builder()
            .authType(authType.applyValue({ args0 -> args0 }))
            .clientId(clientId.applyValue({ args0 -> args0 }))
            .deleteOrUpdateBehavior(
                deleteOrUpdateBehavior?.applyValue({ args0 ->
                    args0.transform({ args0 ->
                        args0
                    }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .principalId(principalId.applyValue({ args0 -> args0 }))
            .roles(roles?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .secret(secret.applyValue({ args0 -> args0 }))
            .userName(userName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ServicePrincipalSecretAuthInfoArgs].
 */
@PulumiTagMarker
public class ServicePrincipalSecretAuthInfoArgsBuilder internal constructor() {
    private var authType: Output<String>? = null

    private var clientId: Output<String>? = null

    private var deleteOrUpdateBehavior: Output<Either<String, DeleteOrUpdateBehavior>>? = null

    private var principalId: Output<String>? = null

    private var roles: Output<List<String>>? = null

    private var secret: Output<String>? = null

    private var userName: Output<String>? = null

    /**
     * @param value The authentication type.
     * Expected value is 'servicePrincipalSecret'.
     */
    @JvmName("jmolfuwbxoxbdate")
    public suspend fun authType(`value`: Output<String>) {
        this.authType = value
    }

    /**
     * @param value ServicePrincipal application clientId for servicePrincipal auth.
     */
    @JvmName("anjuafacibbhkrvf")
    public suspend fun clientId(`value`: Output<String>) {
        this.clientId = value
    }

    /**
     * @param value Indicates whether to clean up previous operation when Linker is updating or deleting
     */
    @JvmName("tsjfldtrnsuywisp")
    public suspend
    fun deleteOrUpdateBehavior(`value`: Output<Either<String, DeleteOrUpdateBehavior>>) {
        this.deleteOrUpdateBehavior = value
    }

    /**
     * @param value Principal Id for servicePrincipal auth.
     */
    @JvmName("lrcywxnbatglevjj")
    public suspend fun principalId(`value`: Output<String>) {
        this.principalId = value
    }

    /**
     * @param value Optional, this value specifies the Azure roles to be assigned. Automatically
     */
    @JvmName("ivfqnxbsqsxcbpsq")
    public suspend fun roles(`value`: Output<List<String>>) {
        this.roles = value
    }

    @JvmName("pdolvjpqscamgihw")
    public suspend fun roles(vararg values: Output<String>) {
        this.roles = Output.all(values.asList())
    }

    /**
     * @param values Optional, this value specifies the Azure roles to be assigned. Automatically
     */
    @JvmName("obfewvrdudvwejnu")
    public suspend fun roles(values: List<Output<String>>) {
        this.roles = Output.all(values)
    }

    /**
     * @param value Secret for servicePrincipal auth.
     */
    @JvmName("nlpffcsoadwoukht")
    public suspend fun secret(`value`: Output<String>) {
        this.secret = value
    }

    /**
     * @param value Username created in the database which is mapped to a user in AAD.
     */
    @JvmName("trwieubqjmuwrksa")
    public suspend fun userName(`value`: Output<String>) {
        this.userName = value
    }

    /**
     * @param value The authentication type.
     * Expected value is 'servicePrincipalSecret'.
     */
    @JvmName("gmbwvlteqtroksbf")
    public suspend fun authType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.authType = mapped
    }

    /**
     * @param value ServicePrincipal application clientId for servicePrincipal auth.
     */
    @JvmName("rnkjmbomcblrhvtw")
    public suspend fun clientId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.clientId = mapped
    }

    /**
     * @param value Indicates whether to clean up previous operation when Linker is updating or deleting
     */
    @JvmName("lngatdenlkyqgjyy")
    public suspend fun deleteOrUpdateBehavior(`value`: Either<String, DeleteOrUpdateBehavior>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deleteOrUpdateBehavior = mapped
    }

    /**
     * @param value Indicates whether to clean up previous operation when Linker is updating or deleting
     */
    @JvmName("fukqlsekhefrbdtl")
    public fun deleteOrUpdateBehavior(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DeleteOrUpdateBehavior>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deleteOrUpdateBehavior = mapped
    }

    /**
     * @param value Indicates whether to clean up previous operation when Linker is updating or deleting
     */
    @JvmName("ayxagdbxympxbelx")
    public fun deleteOrUpdateBehavior(`value`: DeleteOrUpdateBehavior) {
        val toBeMapped = Either.ofRight<String, DeleteOrUpdateBehavior>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deleteOrUpdateBehavior = mapped
    }

    /**
     * @param value Principal Id for servicePrincipal auth.
     */
    @JvmName("duonxhogmtckpowp")
    public suspend fun principalId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.principalId = mapped
    }

    /**
     * @param value Optional, this value specifies the Azure roles to be assigned. Automatically
     */
    @JvmName("gednpngmtihrdpcp")
    public suspend fun roles(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.roles = mapped
    }

    /**
     * @param values Optional, this value specifies the Azure roles to be assigned. Automatically
     */
    @JvmName("litmuaufatfsxdbf")
    public suspend fun roles(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.roles = mapped
    }

    /**
     * @param value Secret for servicePrincipal auth.
     */
    @JvmName("vohvcqdgdhsevysb")
    public suspend fun secret(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.secret = mapped
    }

    /**
     * @param value Username created in the database which is mapped to a user in AAD.
     */
    @JvmName("nyusuesqwvcsencs")
    public suspend fun userName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userName = mapped
    }

    internal fun build(): ServicePrincipalSecretAuthInfoArgs = ServicePrincipalSecretAuthInfoArgs(
        authType = authType ?: throw PulumiNullFieldException("authType"),
        clientId = clientId ?: throw PulumiNullFieldException("clientId"),
        deleteOrUpdateBehavior = deleteOrUpdateBehavior,
        principalId = principalId ?: throw PulumiNullFieldException("principalId"),
        roles = roles,
        secret = secret ?: throw PulumiNullFieldException("secret"),
        userName = userName,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/servicelinker/kotlin/inputs/ServicePrincipalSecretAuthInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicelinker.kotlin.inputs

import com.pulumi.azurenative.servicelinker.inputs.ServicePrincipalSecretAuthInfoArgs.builder
import com.pulumi.azurenative.servicelinker.kotlin.enums.DeleteOrUpdateBehavior
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The authentication info when authType is servicePrincipal secret
 * @property authType The authentication type.
 * Expected value is 'servicePrincipalSecret'.
 * @property clientId ServicePrincipal application clientId for servicePrincipal auth.
 * @property deleteOrUpdateBehavior Indicates whether to clean up previous operation when Linker is updating or deleting
 * @property principalId Principal Id for servicePrincipal auth.
 * @property roles Optional, this value specifies the Azure roles to be assigned. Automatically
 * @property secret Secret for servicePrincipal auth.
 * @property userName Username created in the database which is mapped to a user in AAD.
 */
public data class ServicePrincipalSecretAuthInfoArgs(
    public val authType: Output<String>,
    public val clientId: Output<String>,
    public val deleteOrUpdateBehavior: Output<Either<String, DeleteOrUpdateBehavior>>? = null,
    public val principalId: Output<String>,
    public val roles: Output<List<String>>? = null,
    public val secret: Output<String>,
    public val userName: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.servicelinker.inputs.ServicePrincipalSecretAuthInfoArgs> {
    override fun toJava():
        com.pulumi.azurenative.servicelinker.inputs.ServicePrincipalSecretAuthInfoArgs =
        com.pulumi.azurenative.servicelinker.inputs.ServicePrincipalSecretAuthInfoArgs.builder()
            .authType(authType.applyValue({ args0 -> args0 }))
            .clientId(clientId.applyValue({ args0 -> args0 }))
            .deleteOrUpdateBehavior(
                deleteOrUpdateBehavior?.applyValue({ args0 ->
                    args0.transform({ args0 ->
                        args0
                    }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .principalId(principalId.applyValue({ args0 -> args0 }))
            .roles(roles?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .secret(secret.applyValue({ args0 -> args0 }))
            .userName(userName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ServicePrincipalSecretAuthInfoArgs].
 */
@PulumiTagMarker
public class ServicePrincipalSecretAuthInfoArgsBuilder internal constructor() {
    private var authType: Output<String>? = null

    private var clientId: Output<String>? = null

    private var deleteOrUpdateBehavior: Output<Either<String, DeleteOrUpdateBehavior>>? = null

    private var principalId: Output<String>? = null

    private var roles: Output<List<String>>? = null

    private var secret: Output<String>? = null

    private var userName: Output<String>? = null

    /**
     * @param value The authentication type.
     * Expected value is 'servicePrincipalSecret'.
     */
    @JvmName("yxplppegdblwwejt")
    public suspend fun authType(`value`: Output<String>) {
        this.authType = value
    }

    /**
     * @param value ServicePrincipal application clientId for servicePrincipal auth.
     */
    @JvmName("bffyufldiyogqkod")
    public suspend fun clientId(`value`: Output<String>) {
        this.clientId = value
    }

    /**
     * @param value Indicates whether to clean up previous operation when Linker is updating or deleting
     */
    @JvmName("gwhpbjhqpftjbbcs")
    public suspend
    fun deleteOrUpdateBehavior(`value`: Output<Either<String, DeleteOrUpdateBehavior>>) {
        this.deleteOrUpdateBehavior = value
    }

    /**
     * @param value Principal Id for servicePrincipal auth.
     */
    @JvmName("xsbqutnftybcjqet")
    public suspend fun principalId(`value`: Output<String>) {
        this.principalId = value
    }

    /**
     * @param value Optional, this value specifies the Azure roles to be assigned. Automatically
     */
    @JvmName("nrdksykdbqixnmik")
    public suspend fun roles(`value`: Output<List<String>>) {
        this.roles = value
    }

    @JvmName("bdavouochrstwdta")
    public suspend fun roles(vararg values: Output<String>) {
        this.roles = Output.all(values.asList())
    }

    /**
     * @param values Optional, this value specifies the Azure roles to be assigned. Automatically
     */
    @JvmName("jkcdeumcoiynqtwq")
    public suspend fun roles(values: List<Output<String>>) {
        this.roles = Output.all(values)
    }

    /**
     * @param value Secret for servicePrincipal auth.
     */
    @JvmName("jnsaaclhxjrqwroe")
    public suspend fun secret(`value`: Output<String>) {
        this.secret = value
    }

    /**
     * @param value Username created in the database which is mapped to a user in AAD.
     */
    @JvmName("qpwlbhkpruktewjb")
    public suspend fun userName(`value`: Output<String>) {
        this.userName = value
    }

    /**
     * @param value The authentication type.
     * Expected value is 'servicePrincipalSecret'.
     */
    @JvmName("uulfqgbdeludonwh")
    public suspend fun authType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.authType = mapped
    }

    /**
     * @param value ServicePrincipal application clientId for servicePrincipal auth.
     */
    @JvmName("neyyjfwdmayosqsj")
    public suspend fun clientId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.clientId = mapped
    }

    /**
     * @param value Indicates whether to clean up previous operation when Linker is updating or deleting
     */
    @JvmName("gyxtucgwfguaatyy")
    public suspend fun deleteOrUpdateBehavior(`value`: Either<String, DeleteOrUpdateBehavior>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deleteOrUpdateBehavior = mapped
    }

    /**
     * @param value Indicates whether to clean up previous operation when Linker is updating or deleting
     */
    @JvmName("kcibwimxxnfoyhbq")
    public fun deleteOrUpdateBehavior(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DeleteOrUpdateBehavior>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deleteOrUpdateBehavior = mapped
    }

    /**
     * @param value Indicates whether to clean up previous operation when Linker is updating or deleting
     */
    @JvmName("tafqmhnxxrbreqpw")
    public fun deleteOrUpdateBehavior(`value`: DeleteOrUpdateBehavior) {
        val toBeMapped = Either.ofRight<String, DeleteOrUpdateBehavior>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deleteOrUpdateBehavior = mapped
    }

    /**
     * @param value Principal Id for servicePrincipal auth.
     */
    @JvmName("xsobimwehwlpqleb")
    public suspend fun principalId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.principalId = mapped
    }

    /**
     * @param value Optional, this value specifies the Azure roles to be assigned. Automatically
     */
    @JvmName("jxbnqtctweldswlg")
    public suspend fun roles(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.roles = mapped
    }

    /**
     * @param values Optional, this value specifies the Azure roles to be assigned. Automatically
     */
    @JvmName("nbohvgoqolgfmcjv")
    public suspend fun roles(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.roles = mapped
    }

    /**
     * @param value Secret for servicePrincipal auth.
     */
    @JvmName("dprsjbmawcohtqjt")
    public suspend fun secret(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.secret = mapped
    }

    /**
     * @param value Username created in the database which is mapped to a user in AAD.
     */
    @JvmName("qrkptywpstjvxlrq")
    public suspend fun userName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userName = mapped
    }

    internal fun build(): ServicePrincipalSecretAuthInfoArgs = ServicePrincipalSecretAuthInfoArgs(
        authType = authType ?: throw PulumiNullFieldException("authType"),
        clientId = clientId ?: throw PulumiNullFieldException("clientId"),
        deleteOrUpdateBehavior = deleteOrUpdateBehavior,
        principalId = principalId ?: throw PulumiNullFieldException("principalId"),
        roles = roles,
        secret = secret ?: throw PulumiNullFieldException("secret"),
        userName = userName,
    )
}
